from setuptools import setup

setup(name='sm-distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['sm-distributions'],
      author='Shipra Mahajan',
      author_email='shipra.mahajan@gmail.com',
      zip_safe=False)
